==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dav/l10n/pl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendarz",
    "Todos" : "Zadania",
    "Personal" : "Osobiste",
    "{actor} created calendar {calendar}" : "{actor} utworzył kalendarz {calendar}",
    "You created calendar {calendar}" : "Utworzyłeś kalendarz {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} usunął kalendarz {calendar} .",
    "You deleted calendar {calendar}" : "Usunąłeś kalendarz {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} zaktualizował kalendarz {calendar}",
    "You updated calendar {calendar}" : "Zaktualizowałeś kalendarz {calendar}",
    "You shared calendar {calendar} as public link" : "Udostępniłeś kalendarz {calendar} przez link publiczny",
    "You removed public link for calendar {calendar}" : "Usunąłeś link publiczny do kalendarza {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} współdzieli kalendarz {calendar} z Tobą",
    "You shared calendar {calendar} with {user}" : "Współdzielisz kalendarz {calendar} z {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} współdzieli kalendarz {calendar} z {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} zakończył współdzielenie kalendarza {calendar} z Tobą",
    "You unshared calendar {calendar} from {user}" : "Zakończyłeś współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zakończył współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zakończył współdzielenie kalendarza {calendar} od siebie",
    "You shared calendar {calendar} with group {group}" : "Współdzielisz kalendarz {calendar} z grupą {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} współdzieli kalendarz {calendar} z grupą {group}",
    "You unshared calendar {calendar} from group {group}" : "Zakończyłeś współdzielenie kalendarza {calendar} z grupą {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  nie współdzieli kalendarza {calendar} z grupą {group} .",
    "{actor} created event {event} in calendar {calendar}" : "{actor} utworzył wydarzenie {event} w kalendarzu {calendar}",
    "You created event {event} in calendar {calendar}" : "Utworzyłeś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} usunął wydarzenie {event} z kalendarza {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usunąłeś wydarzenie {event} z kalendarza {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} zaktualizował wydarzenie {event} z kalendarza {calendar}",
    "You updated event {event} in calendar {calendar}" : "Zaktualizowałeś wydarzenie {event} w kalendarzu {calendar}",
    "Busy" : "Czekaj",
    "{actor} created todo {todo} in list {calendar}" : "{actor} utworzył zadanie {todo} na liście {calendar}",
    "You created todo {todo} in list {calendar}" : "Utworzyłeś zadanie {todo} na liście {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} usunął zadanie {todo} z listy {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usunąłeś zadanie {todo} z listy {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} zaktualizował zadanie {todo} na liście {calendar}",
    "You updated todo {todo} in list {calendar}" : "Zaktualizowałeś zadanie {todo} na liście {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} zakończył zadanie {todo} na liście {calendar}",
    "You solved todo {todo} in list {calendar}" : "Zakończyłeś zadanie {todo} na liście {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} otworzył ponownie zadanie {todo} na liście {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otworzyłeś ponownie zadanie {todo} na liście {calendar}",
    "Calendar and tasks" : "Kalendarz i zadania",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
    "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
    "A calendar <strong>todo</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
    "Death of %s" : "Śmierć %s",
    "Contact birthdays" : "Urodziny kontaktu",
    "Calendar:" : "Kalendarz:",
    "Date:" : "Data:",
    "Where:" : "Gdzie:",
    "Description:" : "Opis:",
    "Untitled event" : "Wydarzenie bez tytułu",
    "_%n year_::_%n years_" : ["%n rok","%n lata","%n lat","%n lat"],
    "_%n month_::_%n months_" : ["%n miesiąc","%n miesiące","%n miesięcy","%n miesięcy"],
    "_%n day_::_%n days_" : ["%n dzień","%n dni","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n godzina","%n godziny","%n godzin","%n godziny"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
    "%s (in %s)" : "%s (w %s)",
    "%s (%s ago)" : "%s (%s temu)",
    "Calendar: %s" : "Kalendarz: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Gdzie: %s",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Invitation canceled" : "Zaproszenie anulowane",
    "Invitation updated" : "Zaproszenie zaktualizowane",
    "Invitation" : "Zaproszenie",
    "Title:" : "Tytuł:",
    "Time:" : "Czas:",
    "Location:" : "Lokalizacja:",
    "Link:" : "Link: ",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Uczestnicy:",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "More options …" : "Więcej opcji...",
    "More options at %s" : "Więcej opcji na %s",
    "Contacts" : "Kontakty",
    "System in maintenance mode." : "System w trybie konserwacji.",
    "Upgrade needed" : "Wymagana aktualizacja",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s musisz używać protokołu HTTPS aby móc korzystać z CalDAV i CardDAV w systemach iOS/macOS.",
    "Configures a CalDAV account" : "Konfiguruje konto CalDAV",
    "Configures a CardDAV account" : "Konfiguruje konto CardDAV",
    "Events" : "Wydarzenia",
    "Tasks" : "Zadania",
    "Untitled task" : "Zadanie bez tytułu",
    "Completed on %s" : "Ukończono %s",
    "Due on %s by %s" : "Na dzień %s w %s",
    "Due on %s" : "Na dzień %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Adres WebDAV",
    "There was an error updating your attendance status." : "Wystąpił błąd zmiany stanu uczestnictwa",
    "Please contact the organizer directly." : "Skontaktuj się bezpośrednio z orgnizatorem.",
    "Are you accepting the invitation?" : "Czy akceptujesz zaproszenie?",
    "Tentative" : "Niepewne",
    "Save" : "Zapisz",
    "Your attendance was updated successfully." : "Twoja obecność została zmieniona.",
    "Calendar server" : "Serwer kalendarza",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Zainstaluj także {calendarappstoreopen}aplikację Kalendarz{linkclose} lub {calendardocopen}połącz swój komputer i telefon komórkowy, aby zsynchronizować ↗{linkclose}.",
    "Send invitations to attendees" : "Wyślij zaproszenia do uczestników",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Upewnij się, że poprawnie skonfigurowałeś {emailopen}serwer poczty{linkclose}.",
    "Automatically generate a birthday calendar" : "Automatycznie generuj kalendarz urodzin",
    "Birthday calendars will be generated by a background job." : "Kalendarz urodzin będzie generowany przez uruchomione zadanie w tle.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Dlatego nie będą dostępne natychmiast po włączeniu, ale pojawią się po pewnym czasie.",
    "Send notifications for events" : "Wysyłaj powiadomienia o wydarzeniach",
    "Notifications are sent via background jobs, so these must occur often enough." : "Powiadomienia są wysyłane za pośrednictwem zadań w tle, więc muszą one występować wystarczająco często.",
    "Enable notifications for events via push" : "Włącz powiadomienia o zdarzeniach poprzez push",
    "Hello %s," : "Witaj %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Spotkanie »%1$s« z %2$s zostało anulowane.",
    "The meeting »%1$s« with %2$s was updated." : "Spotkanie »%1$s« z %2$s zostało zaktualizowane.",
    "%1$s invited you to »%2$s«" : "%1$s zaprosił cię do »%2$s«",
    "When:" : "Kiedy:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-21.0.1-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dav/l10n/pl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendarz",
    "Todos" : "Zadania",
    "Personal" : "Osobiste",
    "{actor} created calendar {calendar}" : "{actor} utworzył kalendarz {calendar}",
    "You created calendar {calendar}" : "Utworzyłeś kalendarz {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} usunął kalendarz {calendar} .",
    "You deleted calendar {calendar}" : "Usunąłeś kalendarz {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} zaktualizował kalendarz {calendar}",
    "You updated calendar {calendar}" : "Zaktualizowałeś kalendarz {calendar}",
    "You shared calendar {calendar} as public link" : "Udostępniłeś kalendarz {calendar} przez link publiczny",
    "You removed public link for calendar {calendar}" : "Usunąłeś link publiczny do kalendarza {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} udostępnił kalendarz {calendar} dla Ciebie",
    "You shared calendar {calendar} with {user}" : "Udostępniłeś kalendarz {calendar} dla {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} udostępnił kalendarz {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} zakończył udostępnianie kalendarza {calendar} dla Ciebie",
    "You unshared calendar {calendar} from {user}" : "Zakończyłeś udostępnianie kalendarza {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zakończył udostępnianie kalendarza {calendar} dla {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zakończył udostępnianie kalendarza {calendar} od siebie",
    "You shared calendar {calendar} with group {group}" : "Udostępniłeś kalendarz {calendar} dla grupy {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} udostępnił kalendarz {calendar} dla grupy {group}",
    "You unshared calendar {calendar} from group {group}" : "Zakończyłeś udostępnianie kalendarza {calendar} dla grupy {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} zakończył udostępnianie kalendarza {calendar} dla grupy {group} .",
    "{actor} created event {event} in calendar {calendar}" : "{actor} utworzył wydarzenie {event} w kalendarzu {calendar}",
    "You created event {event} in calendar {calendar}" : "Utworzyłeś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} usunął wydarzenie {event} z kalendarza {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usunąłeś wydarzenie {event} z kalendarza {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} zaktualizował wydarzenie {event} z kalendarza {calendar}",
    "You updated event {event} in calendar {calendar}" : "Zaktualizowałeś wydarzenie {event} w kalendarzu {calendar}",
    "Busy" : "Czekaj",
    "{actor} created todo {todo} in list {calendar}" : "{actor} utworzył zadanie {todo} na liście {calendar}",
    "You created todo {todo} in list {calendar}" : "Utworzyłeś zadanie {todo} na liście {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} usunął zadanie {todo} z listy {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usunąłeś zadanie {todo} z listy {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} zaktualizował zadanie {todo} na liście {calendar}",
    "You updated todo {todo} in list {calendar}" : "Zaktualizowałeś zadanie {todo} na liście {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} zakończył zadanie {todo} na liście {calendar}",
    "You solved todo {todo} in list {calendar}" : "Zakończyłeś zadanie {todo} na liście {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} otworzył ponownie zadanie {todo} na liście {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otworzyłeś ponownie zadanie {todo} na liście {calendar}",
    "Calendar and tasks" : "Kalendarz i zadania",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
    "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
    "A calendar <strong>todo</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
    "Contact birthdays" : "Urodziny kontaktu",
    "Death of %s" : "Śmierć %s",
    "Calendar:" : "Kalendarz:",
    "Date:" : "Data:",
    "Where:" : "Gdzie:",
    "Description:" : "Opis:",
    "Untitled event" : "Wydarzenie bez tytułu",
    "_%n year_::_%n years_" : ["%n rok","%n lata","%n lat","%n lat"],
    "_%n month_::_%n months_" : ["%n miesiąc","%n miesiące","%n miesięcy","%n miesięcy"],
    "_%n day_::_%n days_" : ["%n dzień","%n dni","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n godzina","%n godziny","%n godzin","%n godziny"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
    "%s (in %s)" : "%s (w %s)",
    "%s (%s ago)" : "%s (%s temu)",
    "Calendar: %s" : "Kalendarz: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Gdzie: %s",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "Invitation canceled" : "Zaproszenie anulowane",
    "Invitation updated" : "Zaproszenie zaktualizowane",
    "Invitation" : "Zaproszenie",
    "Title:" : "Tytuł:",
    "Time:" : "Czas:",
    "Location:" : "Lokalizacja:",
    "Link:" : "Link: ",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Uczestnicy:",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "More options …" : "Więcej opcji…",
    "More options at %s" : "Więcej opcji na %s",
    "Contacts" : "Kontakty",
    "System in maintenance mode." : "System w trybie konserwacji.",
    "Upgrade needed" : "Wymagana aktualizacja",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s musisz używać protokołu HTTPS aby móc korzystać z CalDAV i CardDAV w systemach iOS/macOS.",
    "Configures a CalDAV account" : "Konfiguruje konto CalDAV",
    "Configures a CardDAV account" : "Konfiguruje konto CardDAV",
    "Events" : "Wydarzenia",
    "Tasks" : "Zadania",
    "Untitled task" : "Zadanie bez tytułu",
    "Completed on %s" : "Ukończono %s",
    "Due on %s by %s" : "Na dzień %s w %s",
    "Due on %s" : "Na dzień %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Adres WebDAV",
    "There was an error updating your attendance status." : "Wystąpił błąd zmiany stanu uczestnictwa",
    "Please contact the organizer directly." : "Skontaktuj się bezpośrednio z orgnizatorem.",
    "Are you accepting the invitation?" : "Czy akceptujesz zaproszenie?",
    "Tentative" : "Niepewne",
    "Save" : "Zapisz",
    "Your attendance was updated successfully." : "Twoja obecność została pomyślnie zaktualizowana.",
    "Calendar server" : "Serwer kalendarza",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Zainstaluj także {calendarappstoreopen}aplikację Kalendarz{linkclose} lub {calendardocopen}połącz swój komputer i telefon komórkowy, aby zsynchronizować ↗{linkclose}.",
    "Send invitations to attendees" : "Wyślij zaproszenia do uczestników",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Upewnij się, że poprawnie skonfigurowałeś {emailopen}serwer poczty{linkclose}.",
    "Automatically generate a birthday calendar" : "Automatycznie generuj kalendarz urodzin",
    "Birthday calendars will be generated by a background job." : "Kalendarz urodzin będzie generowany przez uruchomione zadanie w tle.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Dlatego nie będą dostępne natychmiast po włączeniu, ale pojawią się po pewnym czasie.",
    "Send notifications for events" : "Wysyłaj powiadomienia o wydarzeniach",
    "Notifications are sent via background jobs, so these must occur often enough." : "Powiadomienia są wysyłane za pośrednictwem zadań w tle, więc muszą one występować wystarczająco często.",
    "Enable notifications for events via push" : "Włącz powiadomienia o zdarzeniach poprzez push",
    "Hello %s," : "Witaj %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Spotkanie »%1$s« z %2$s zostało anulowane.",
    "The meeting »%1$s« with %2$s was updated." : "Spotkanie »%1$s« z %2$s zostało zaktualizowane.",
    "%1$s invited you to »%2$s«" : "%1$s zaprosił cię do »%2$s«",
    "When:" : "Kiedy:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
